Introduction to pysiss
======================

This is a python module designed to make it easy to perform analysis based on SISS services (including boreholes & geological measurements, raster and vector map data, and vocabularies) within Python using your favourite Python libraries. 

**Warning** - this library is in a pre-pre-pre-alpha state and could change without warning.

For more details, see the Github page: https://github.com/pysiss/pysiss

This library is released under the CSIRO BSD/MIT license: https://github.com/pysiss/pysiss/blob/master/LICENSE.txt